"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const utils_1 = __importDefault(require("./utils"));
function useEventListener(listener, event, fn, options) {
    let { addListenerKey, removeListenerKey } = options || {};
    (0, react_1.useEffect)(() => {
        function cb(...args) {
            fn(...args);
        }
        let listenInstance;
        if (!addListenerKey)
            addListenerKey = utils_1.default.findAvailableKey(listener, ['on', 'addEventListener', 'addListener']);
        if (addListenerKey) {
            listenInstance = listener[addListenerKey](event, cb);
        }
        else {
            console.error('useEventListener():', "Couldn't find addListener function. Try to set key manually.");
        }
        return () => {
            // instance type unsubscribe
            if (listenInstance) {
                if (typeof listenInstance === 'function') {
                    return listenInstance();
                }
                if ('remove' in listenInstance) {
                    listener.remove();
                    return null;
                }
            }
            // standard way unsubscribe
            if (!removeListenerKey) {
                removeListenerKey = utils_1.default.findAvailableKey(listener, ['off', 'removeEventListener', 'removeListener']);
            }
            if (removeListenerKey) {
                listener[removeListenerKey](event, cb);
            }
            else {
                console.error('useEventListener():', "Couldn't find removeListener function. Try to set key manually.");
            }
        };
    }, []);
}
exports.default = useEventListener;
//# sourceMappingURL=useEventListener.js.map